==> sumo_1.24.0+dfsg1.orig.tar.xz: sumo-1_24_0/tests/netedit/network/junctions/contextual_menu/tls/add_joined_tls/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2025 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

sys.path.append(os.path.join(os.environ.get("SUMO_HOME", "."), "tools"))
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart()

# recompute
netedit.computeJunctions()

# rebuild network
netedit.computeJunctions()

# go to select mode
netedit.changeMode("select")

# select three junctions
netedit.leftClick(referencePosition, netedit.positions.network.junction.cross.left)
netedit.leftClick(referencePosition, netedit.positions.network.junction.cross.center)
netedit.leftClick(referencePosition, netedit.positions.network.junction.cross.right)

# transform to roundAbout
netedit.contextualMenuOperation(referencePosition, netedit.positions.network.junction.cross.center,
                                netedit.contextualMenu.junction.addJoinedTLS)

# recompute
netedit.computeJunctions()

# Check undos
netedit.undo(referencePosition, 1)

# recompute
netedit.computeJunctions()

# check redos
netedit.redo(referencePosition, 1)

# save Netedit config
netedit.saveExistentShortcut("neteditConfig")

# adjust elements
netedit.typeKey("space")

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.25.0+dfsg1.orig.tar.xz: sumo-1_25_0/tests/netedit/network/junctions/contextual_menu/tls/add_joined_tls/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2025 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

sys.path.append(os.path.join(os.environ.get("SUMO_HOME", "."), "tools"))
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart()

# recompute
netedit.computeJunctions()

# rebuild network
netedit.computeJunctions()

# go to select mode
netedit.changeMode("select")

# select three junctions
netedit.leftClick(referencePosition, netedit.positions.network.junction.cross.left)
netedit.leftClick(referencePosition, netedit.positions.network.junction.cross.center)
netedit.leftClick(referencePosition, netedit.positions.network.junction.cross.right)

# transform to roundAbout
netedit.contextualMenuOperation(referencePosition, netedit.positions.network.junction.cross.center,
                                netedit.contextualMenu.junction.addJoinedTLS)

# recompute
netedit.computeJunctions()

# Check undos
netedit.undo(referencePosition, 1)

# recompute
netedit.computeJunctions()

# check redos
netedit.redo(referencePosition, 1)

# save Netedit config
netedit.saveExistentFile("neteditConfig")

# adjust elements
netedit.typeKey("space")

# quit netedit
netedit.quit(neteditProcess)
